==> django-crypto-fields-0.1.1.tar.gz: django-crypto-fields-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
import os
from setuptools import setup
from setuptools import find_packages

#with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
#    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-crypto-fields',
    version='0.1.1',
    author=u'Erik van Widenfelt',
    author_email='ew2789@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    url='http://github/erikvw/django-crypto-fields',
    license='GPL licence, see LICENCE',
    description='Add encrypted field classes and more to your Django models.',
    # long_description=README,
    zip_safe=False,
    keywords='django fields encryption security',
    install_requires=[
        'Django>=1.7',
        'pycrypto>=2.6.1',
        'django-extensions>=1.5.5',
        'unipath>=1.1',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.4',
        'Topic :: Security :: Cryptography',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)

==> django-crypto-fields-0.1.2.tar.gz: django-crypto-fields-0.1.2/setup.py <==
# -*- coding: utf-8 -*-
import os
from setuptools import setup
from setuptools import find_packages

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-crypto-fields',
    version='0.1.2',
    author=u'Erik van Widenfelt',
    author_email='ew2789@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    url='http://github/erikvw/django-crypto-fields',
    license='GPL licence, see LICENCE',
    description='Add encrypted field classes and more to your Django models.',
    long_description=README,
    zip_safe=False,
    keywords='django fields encryption security',
    install_requires=[
        'Django>=1.7',
        'pycrypto>=2.6.1',
        'django-extensions>=1.5.5',
        'unipath>=1.1',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.4',
        'Topic :: Security :: Cryptography',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
